@@ -19,7 +19,7 @@ def _format_card(response):
             'expiration_year': response['card']['expiration_year'],
         }
         
-    if 'card_data' in response:
+    if 'card_data' in response and not 'tokens' in response['card_data']:
         return {
             'id': '',
             'card_type': '',
@@ -44,16 +44,15 @@ def _format_card(response):
 
 
 def _format(response):
-    if response['status'] == 'accredited':
+    if response['status'] in ['accredited', 'approved']:
         response['status'] = 'approved'
         response['status_detail'] = 'accredited'
-    elif response['status'] == 'approved':
-        response['status_detail'] = 'not_accredited'
     elif response['status'] == 'rejected':
         response['status_detail'] = 'rejected'
     result = {
         'id': response['site_transaction_id'],
-        'transaction_amount': response['amount']/100,
+        'payment_id': response['id'],
+        'transaction_amount': response['amount'] / 100,
         'date_created': parse_date(response['date']),
         'status': response['status'],
         'status_detail': response['status_detail'],
@@ -64,14 +63,14 @@ def _format(response):
 
 
 class Payment:
-    def __init__(self, url, private_key: str, public_key: str, merchant_name: str, site_ids: dict,
-                 site_ids_cadena: dict = None):
+    def __init__(self, url: str, private_key: str, public_key: str, merchant_name: str, site_id: str,
+                 site_id_cadena: str):
         self.url = url
         self.private_key = private_key
         self.public_key = public_key
         self.merchant_name = merchant_name
-        self.site_ids = site_ids
-        self.site_ids_cadena = site_ids_cadena
+        self.site_id = site_id
+        self.site_id_cadena = site_id_cadena
         self.headers = {
             'apikey': self.private_key,
             'Content-Type': 'application/json',
@@ -81,6 +80,7 @@ class Payment:
     def create(self, payment_data: dict):
         site_transaction_id = ''.join(random.choices(string.ascii_letters + string.digits, k=10))
         total_amount = round(payment_data['transaction_amount'], 2) * 100  # se multiplica por 100; no acepta decimales
+        installments = payment_data['installments'] if 'installments' in payment_data else 1
         body = {
             'customer': {
                 'id': payment_data['payer']['decidir_id'],
@@ -88,41 +88,35 @@ class Payment:
             },
             'site_transaction_id': site_transaction_id,
             'token': payment_data['token'],
-            'payment_method_id': 1,    # Peso Argentino
-            'bin': payment_data['bin'],    # primeros 6 digitos de la tarjeta
+            'payment_method_id': 1,         # Peso Argentino
+            'bin': payment_data['bin'],     # primeros 6 digitos de la tarjeta
             'currency': 'ARS',
-            'installments': 1,
             'payment_type': 'single',
-            'establishment_name': self.merchant_name,  # opcional
+            'establishment_name': self.merchant_name,
             'sub_payments': []
         }
-        if 'application_fee' not in payment_data:
-            body['amount'] = total_amount
-            if payment_data['payment_type'] == 'cobro_por_uso':
-                body['site_id'] = self.site_ids['cobro_por_uso']
-            elif payment_data['payment_type'] == 'checkout':
-                body['site_id'] = self.site_ids['checkout']
-            elif payment_data['payment_type'] == 'cobros_recurrentes':
-                body['site_id'] = self.site_ids['cobros_recurrentes']
 
+        if 'application_fee' not in payment_data:   # El pago va 100% al hijo
+            body['amount'] = total_amount
+            body['site_id'] = self.site_id
+            body['installments'] = installments
         else:
-            body['payment_type'] = 'distributed'
             application_fee = round(payment_data['application_fee'], 2) * 100
+            body['payment_type'] = 'distributed'
             body['sub_payments'] = [
                 {
-                    'site_id': payment_data['seller_site_id'],
-                    'installments': 1,
-                    'amount': total_amount - application_fee
-                }, {
-                    'site_id': self.site_ids['distributed'],
-                    'installments': 1,
+                    'site_id': self.site_id_cadena,
+                    'installments': installments,
                     'amount': application_fee
+                }, {
+                    'site_id': self.site_id,
+                    'installments': installments,
+                    'amount': total_amount - application_fee
                 }
             ]
 
         # Si viene informacion adicional
         additional_information = [
-            'installments',
             'establishment_name'
         ]
         for item in additional_information:
