@@ -57,8 +57,8 @@ class Payment:
 
         if 'payer' in payment_data:
             payment_data_mp["payer"] = {
-                "first_name": payment_data['payer']["nombre"],
-                "last_name": payment_data['payer']["apellido"],
+                "first_name": payment_data['payer']["first_name"],
+                "last_name": payment_data['payer']["last_name"],
                 "address": None
             }
             if 'mercadopago_id' in payment_data['payer']:
